==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TemplateCellUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateCellUpdatingEventArgsDescription } from "./TemplateCellUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let TemplateCellUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateCellUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateCellUpdatingEventArgsDescriptionMetadata.a == null) {
                TemplateCellUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateCellUpdatingEventArgsDescriptionMetadata.c(TemplateCellUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(TemplateCellUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(TemplateCellUpdatingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            TemplateCellUpdatingEventArgsDescriptionMetadata.b(a);
            a.ac("TemplateCellUpdatingEventArgs", () => new TemplateCellUpdatingEventArgsDescription());
            a.ab("TemplateCellUpdatingEventArgs", TemplateCellUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    TemplateCellUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(TemplateCellUpdatingEventArgsDescriptionMetadata, 'TemplateCellUpdatingEventArgsDescriptionMetadata');
    TemplateCellUpdatingEventArgsDescriptionMetadata.a = null;
    return TemplateCellUpdatingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/TemplateCellUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateCellUpdatingEventArgsDescription } from "./TemplateCellUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let TemplateCellUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateCellUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateCellUpdatingEventArgsDescriptionMetadata.a == null) {
                TemplateCellUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateCellUpdatingEventArgsDescriptionMetadata.c(TemplateCellUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(TemplateCellUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(TemplateCellUpdatingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            TemplateCellUpdatingEventArgsDescriptionMetadata.b(a);
            a.ae("TemplateCellUpdatingEventArgs", () => new TemplateCellUpdatingEventArgsDescription());
            a.ad("TemplateCellUpdatingEventArgs", TemplateCellUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    TemplateCellUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(TemplateCellUpdatingEventArgsDescriptionMetadata, 'TemplateCellUpdatingEventArgsDescriptionMetadata');
    TemplateCellUpdatingEventArgsDescriptionMetadata.a = null;
    return TemplateCellUpdatingEventArgsDescriptionMetadata;
})();
